pub fn frustum(
left: f32,
right: f32,
bottom: f32,
top: f32,
near: f32,
far: f32,
) -> Mat4Expand description
Creates a perspective projection matrix from a frustum for use with OpenGL.
Expects a right-handed Y-up view space input. Outputs NDC with Z in [-1, 1] and Y-up.
This is the OpenGL glFrustum equivalent.
See https://registry.khronos.org/OpenGL-Refpages/gl2.1/xhtml/glFrustum.xml
Panics
Will panic if near or far are less than or equal to zero when glam_assert is enabled.